@@ -3,6 +3,7 @@ from django.conf import settings
 from django.db import models
 from django.utils.safestring import mark_safe
 from django.utils.html import escape
+from django.utils.encoding import smart_text
 
 from markupfield import widgets
 from markupfield import markup
@@ -51,7 +52,9 @@ class Markup(object):
 
     # allows display via templates to work without safe filter
     def __unicode__(self):
-        return mark_safe(self.rendered)
+        return mark_safe(smart_text(self.rendered))
+
+    __str__ = __unicode__
 
 
 class MarkupDescriptor(object):
@@ -153,7 +156,9 @@ class MarkupField(models.TextField):
 
     def value_to_string(self, obj):
         value = self._get_val_from_obj(obj)
-        return value.raw
+        if hasattr(value, 'raw'):
+            return value.raw
+        return value
 
     def formfield(self, **kwargs):
         defaults = {'widget': widgets.MarkupTextarea}
